
// navigateur.js
var verificationJsNavigateur = function () {
	
	// Récupération des données depuis le formulaire
	var fields = {
		nom: document.getElementById('nom').value,
		email: document.getElementById('email').value
	}
	
	// Validation des données
	var resultVerif = verificationMultiPlateforme(fields);
	var ok = true;
	
	// Affichage des (éventuels) messages d'erreurs
	if (resultVerif.nom.ok === false) {
		document.getElementById('error-nom').style.display = 'block';
		ok = false;
	} else {
		document.getElementById('error-nom').style.display = 'none';
	}
	
	if (resultVerif.email.ok === false) {
		document.getElementById('error-email').style.display = 'block';
		ok = false;
	} else {
		document.getElementById('error-email').style.display = 'none';
	}
	
	return ok;
};
