<?php
$ctx = new JSContext();

function fonctionPhp1($who) { return "Hello, $who!"; }
$ctx->registerFunction('fonctionPhp1', 'fonctionPhp1NomJs');

$a = $ctx->evaluateScript(file_get_contents(__DIR__ . '/test.js'));
var_dump($a);
