
var str = '';

// Accès à un entier
str += 'entier = ' + entier + '\n';
str += '\n';

// Accès à une liste
var i;
str += 'liste : length = ' + liste.length + '\n';   // undefined !
for (i = 0 ; i < 3 ; i++) {
	str += '  liste[' + i + '] => ' + liste[i] + '\n';
}
str += '\n';

// Accès à un objet
str += 'obj.a => ' + obj.a + '\n';
str += 'obj.pi => ' + obj.pi + '\n';
str += 'obj.str => ' + obj.str + '\n';
str += '\n';

// Modification d'un objet depuis le code JS
obj2.second = 'There!';

// Pour le retour de la chaîne de caractères vers PHP
str;
