

var test = function () {
	var result = pdo.query('select * from user order by nom desc');
	var row, str = '';
	while (row = result.fetch()) {
		str += row.id + '\t' + row.nom + '\t' + row.email + '\n';
	}
	return str;
};
test();


