<?php
$ctx = new JSContext();

function fonctionPhp1($who) {
    return "Hello, $who!";
}
$ctx->registerFunction('fonctionPhp1', 'fonctionPhp1NomJs');


$ctx->registerFunction(function ($who) {
    return "Hello par closure, $who!";
}, 'fonctionPhp2NomJs');


$js = file_get_contents(__DIR__ . '/test.js');
echo '<pre>' . htmlspecialchars($js) . '</pre>';

$a = $ctx->evaluateScript($js);
var_dump($a);
