
// verif-form.js
var verificationMultiPlateforme = function (fields) {
	var result = {
		nom: {
			ok: false
		},
		email: {
			ok: false
		}
	};
	
	if (fields.nom != '') {
		result.nom.ok = true;
	}
	if (fields.email.indexOf('@') != -1) {
		result.email.ok = true;
	}
	
	return result;
};
