create table user (id integer primary key autoincrement, nom varchar(64), email varchar(128));
insert into user (nom, email) values ('Test1', 'test1@example.com');
insert into user (nom, email) values ('Test2', 'test2@example.com');
insert into user (nom, email) values ('Test3', 'test3@example.com');
