<?php
$ctx = new JSContext();

$ctx->registerFunction(function ($who) {
    return "Hello par closure, $who!";
}, 'fonctionPhp2NomJs');

$a = $ctx->evaluateScript(file_get_contents(__DIR__ . '/test.js'));
var_dump($a);
