<?php


$dsn = 'sqlite:' . __DIR__ . '/db-1.sqlite';
$pdo = new PDO($dsn);

$ctx = new JSContext();
$ctx->assign('pdo', $pdo);

$a = $ctx->evaluateScript(file_get_contents(__DIR__ . '/test.js'));
echo $a;


