
var xmlString = '<?xml version="1.0" ?>' +
	'<root>' +
    '    <user id="1">' +
	'        <name>NOM-1</name>' +
	'    </user>' +
	'    <user id="2">' +
	'        <name>NOM-2</name>' +
	'    </user>' +
	'</root>';

// Chargement du contenu XML
var dom = new DOMDocument();
dom.loadXML(xmlString);

var xpath = new DOMXPath(dom);

// Récupération du nom de l'utilisation d'id=2
var nodesList = xpath.query('//user[@id="2"]/name');

var i;
for (i = 0 ; i < nodesList.length ; i++) {
	print('name = ' + nodesList.item(i).nodeValue + '\n');
}
